clearvars; clc;

% V mapi podatki naredi datoteko tocke_ITRF2014_izbor.csv, ki vsebuje samo tvoje tocke
datoteka_tocke = "..\podatki\tocke_ITRF2014_izbor.csv";

tocke = readtable(datoteka_tocke, Delimiter=';', TextType='string');
% imena stolpcev so privzeta iz glave datoteke:
% stolpci: id | X | Y | Z| vX | vY | vZ | NNR_NUVEL_1A | NNR_MORVEL56 | ITRF2014_PMM

% IZBERI MODEL (ostala dva naj bosta zakomentirana)
model = "NNR_NUVEL_1A";
% model = "NNR_MORVEL56";
% model = "ITRF2014_PMM";
R = 6371000;
datoteka_rezultati_model = strcat('..\rezultati\tocke_ITRF2014-', model, '.txt');
fout = fopen(datoteka_rezultati_model, 'w');
    
fprintf(fout, "           [°]           [°]      [m/leto]  [m/leto]  [m/leto]\n");
fprintf(fout, " id        lat           lon         ve        vn        vu        v2d      azi\n");

for i = 1 : height(tocke)

    switch model
        case "NNR_NUVEL_1A"
            plosca = tocke.NNR_NUVEL_1A(i);
        case "NNR_MORVEL56"
            plosca = tocke.NNR_MORVEL56(i);
        case "ITRF2014_PMM"
            plosca = tocke.ITRF2014_PMM(i);
        otherwise
            error("Napačna oznaka modela gibanja tektonskih plošč.")
    end
    
    % Napiši funkcijo xyz2fila, ki kot vhodne argumente sprejme 3D kartezične koordinate (X, Y, Z)
    % in polmer Zemlje R ter vrne geografsko širino in dolžino (fi, la).
    % Pazi na enote.
    % PROTOTIP FUNKCIJE: function [X, Y, Z] = fila2xyz(fi_deg, la_deg, R) 
    [lat, lon] = xyz2fila(tocke.X(i), tocke.Y(i), tocke.Z(i));
    

    % Uporabi že napisano funkcijo get_Euler_vector (uporaba je razložena v funkciji).
    [W, FI, LA] = get_Euler_vector(plosca, model);
    

    % Napiši funkcijo ev2rv, ki kot vhodne parametre sprejme parametre Eulerjevega vektorja (rezultat
    % funkcije get_Euler_vector) in ga pretvori v rotacijski vektor (enačbe (5) v navodilh).
    % PROTOTIP FUNKCIJE: function [wx, wy, wz] = ev2rv(W, FI_deg, LA_deg)
    [wx, wy, wz] = ev2rv(W, FI, LA);
    

    % Napiši funkcijo get_velocity_vector, ki kot vhodne parametre sprejme 3D kartezične koordinate
    % in komponente rotacijskega vektorja, vrne pa komponente absolutnega vektorja hitrosti v 
    % ECEF koordinatnem sistemu (enačba (3) v navodilh).
    % PROTOTIP FUNKCIJE: function [vx, vy, vz] = get_velocity_vector(X, Y, Z, wx, wy, wz)
    [vx, vy, vz] = get_velocity_vector(tocke.X(i), tocke.Y(i), tocke.Z(i), wx, wy, wz);


    % Napiši funkcijo vxyz2vneu, ki kot vhodne parametre sprejme komponente absolutnega vektorja
    % hitrosti v ECEF koordinatnem sistemu in vrne komponente absolutnega vektorja hitrosti
    % v LG koordinatnem sistemu (enačbe (6) v navodilh).
    % PROTOTIP FUNKCIJE: function [vn, ve, vu] = vxyz2vneu(vx, vy, vz, fi_deg, la_deg)
    [vn, ve, vu] = vxyz2vneu(vx, vy, vz, lat, lon);


    v2d = ...;
    azi = ...;    % pazi na kvadrante
    

    fprintf(fout, "%s %12.7f  %12.7f  %8.4f  %8.4f  %8.4f  %8.4f  %8.4f\n", ...
        tocke.id(i), lat, lon, ve, vn, vu, v2d, azi);
end

fclose(fout);


% PRETVORBA DEJANSKIH VEKTORJEV HITROSTI IZ ECEF V LG KOORDINATNI SISTEM
datoteka_rezultati_dejanski = "..\rezultati\tocke_ITRF2014-dejanski.txt";
fout_dejanski = fopen(datoteka_rezultati_dejanski, 'w');
fprintf(fout_dejanski, "           [°]           [°]      [m/leto]  [m/leto]  [m/leto]\n");
fprintf(fout_dejanski, " id        lat           lon         ve        vn        vu        v2d      azi\n");

for i = 1 : height(tocke)
    [lat, lon] = xyz2fila(tocke.X(i), tocke.Y(i), tocke.Z(i));

    [vn, ve, vu] = vxyz2vneu(tocke.vX(i), tocke.vY(i), tocke.vZ(i), lat, lon);
    
    v2d = ...;
    azi = ...;    % pazi na kvadrante
    
    
    fprintf(fout_dejanski, "%s %12.7f  %12.7f  %8.4f  %8.4f  %8.4f  %8.4f  %8.4f\n", ...
        tocke.id(i), lat, lon, ve, vn, vu, v2d, azi);
end

fclose(fout_dejanski);
